Right<A, B> constructor
Right<A, B> (
- B value
Constructs a Right instance that holds the provided value.
Implementation
Right(this.value);
Constructs a Right instance that holds the provided value.
Right(this.value);