Identity<A> constructor
Identity<A> (
- A value
Constructs an Identity instance that holds the provided value.
Implementation
Identity(this.value);
Constructs an Identity instance that holds the provided value.
Identity(this.value);